plot_slopes: Visualize response-contingency slopes

Description Usage Arguments Value Examples

Description

Visualize response-contingency slopes

Usage

1
2
3
plot_slopes(data = NULL, r_id = "r_id", response = "response",
  contingency = "contingency", xname = NULL, yname = NULL,
  groupfactor = NULL, gflevels = NULL, linear = T)

Arguments

data

data to use for plotting

r_id

column of rater idenitfiers

response

column of responses (y-axis)

contingency

column containing values that ratings are contingent on (x-axis)

xname

custom name for x-axis

yname

custom name for y-axis

groupfactor

factor/grouping variable (color and linetype)

gflevels

vector of custom labels for factor levels

linear

logical argument indicating whether to plot linear function or nonlinear

Value

plot of the individual slopes and overall slope

Examples

1
2
3
4
# plot_slopes(sloper_exdat, response = "strength_rating", contingency = "t_measured_strength",
#            yname = "Stregth Rating", xname = "Target Strength",
#            groupfactor = "ratersex", linear = F, gflevels = c("Men", "Women"))
# plot_slopes(sloper_exdat, response = "strength_rating", contingency = "t_measured_strength")

durkeepk/sloper documentation built on May 17, 2019, 10 a.m.