Description Usage Arguments Value Examples
Extract response-contingency slopes
1 2 3 | get_slopes(data = NULL, r_id = "r_id", t_id = "t_id",
response = "response", contingency = "contingency",
compress = "none", maximal = T)
|
data |
data to use when fitting mixed model. |
r_id |
column of rater idenitfiers. |
t_id |
column of target identifiers. |
response |
column of responses (e.g., ratings, scores) |
contingency |
column containing values that ratings are contingent on |
compress |
column to compress data by ('rater' or 'target'). Default is no compression. |
maximal |
Should random slopes be specified for both targets and raters [T] or just targets [F]. |
New data frame containing individual slopes and intercepts representing the relationship between ratings and contingencies for each rater.
1 2 3 | ## get_slopes(sloper_exdat, r_id = "r_id", t_id = "t_id",
## response = "strength_rating", contingency = "target_strength_ave", compress = "rater")
## get_slopes(sloper_exdat, "strength_rating","target_strength_ave")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.