Description Usage Arguments Value Examples
Visualize response-contingency slopes
1 2 3 |
data |
data to use for plotting |
r_id |
column of rater idenitfiers |
response |
column of responses (y-axis) |
contingency |
column containing values that ratings are contingent on (x-axis) |
xname |
custom name for x-axis |
yname |
custom name for y-axis |
groupfactor |
factor/grouping variable (color and linetype) |
gflevels |
vector of custom labels for factor levels |
linear |
logical argument indicating whether to plot linear function or nonlinear |
plot of the individual slopes and overall slope
1 2 3 4 | # plot_slopes(sloper_exdat, response = "strength_rating", contingency = "t_measured_strength",
# yname = "Stregth Rating", xname = "Target Strength",
# groupfactor = "ratersex", linear = F, gflevels = c("Men", "Women"))
# plot_slopes(sloper_exdat, response = "strength_rating", contingency = "t_measured_strength")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.